package com.link.core.mq.cmq.Tools;

import java.net.URLEncoder;
import java.util.Iterator;
import java.util.Random;
import java.util.TreeMap;

public class CMQClient {
   protected String CURRENT_VERSION = "SDK_JAVA_1.3";
   protected String endpoint;
   protected String path;
   protected String secretId;
   protected String secretKey;
   protected String method;
   protected String signMethod;

   public CMQClient(String endpoint, String path, String secretId, String secretKey, String method) {
      this.endpoint = endpoint;
      this.path = path;
      this.secretId = secretId;
      this.secretKey = secretKey;
      this.method = method;
      this.signMethod = "sha1";
   }

   public void setSignMethod(String signMethod) {
      if (signMethod != "sha1" && signMethod != "sha256") {
         throw new CMQClientException("Only support sha256 or sha1");
      } else {
         this.signMethod = signMethod;
      }
   }

   public String call(String action, TreeMap<String, String> param) throws Exception {
      String rsp = "";

      try {
         param.put("Action", action);
         param.put("Nonce", Integer.toString((new Random()).nextInt(Integer.MAX_VALUE)));
         param.put("SecretId", this.secretId);
         param.put("Timestamp", Long.toString(System.currentTimeMillis() / 1000L));
         param.put("RequestClient", this.CURRENT_VERSION);
         if (this.signMethod == "sha256") {
            param.put("SignatureMethod", "HmacSHA256");
         } else {
            param.put("SignatureMethod", "HmacSHA1");
         }

         String host = "";
         if (this.endpoint.startsWith("https")) {
            host = this.endpoint.substring(8);
         } else {
            host = this.endpoint.substring(7);
         }

         String src = "";
         src = src + this.method + host + this.path + "?";
         boolean flag = false;

         String req;
         for(Iterator var7 = param.keySet().iterator(); var7.hasNext(); flag = true) {
            req = (String)var7.next();
            if (flag) {
               src = src + "&";
            }

            src = src + req.replace("_", ".") + "=" + (String)param.get(req);
         }

         param.put("Signature", CMQTool.sign(src, this.secretKey, this.signMethod));
         String url = "";
         req = "";
         Iterator var9;
         String key;
         if ("GET".equals(this.method)) {
            url = this.endpoint + this.path + "?";
            flag = false;

            for(var9 = param.keySet().iterator(); var9.hasNext(); flag = true) {
               key = (String)var9.next();
               if (flag) {
                  url = url + "&";
               }

               url = url + key + "=" + URLEncoder.encode((String)param.get(key), "utf-8");
            }

            if (url.length() > 2048) {
               throw new CMQClientException("URL length is larger than 2K when use GET method");
            }
         } else {
            url = this.endpoint + this.path;
            flag = false;

            for(var9 = param.keySet().iterator(); var9.hasNext(); flag = true) {
               key = (String)var9.next();
               if (flag) {
                  req = req + "&";
               }

               req = req + key + "=" + URLEncoder.encode((String)param.get(key), "utf-8");
            }
         }

         int userTimeout = 0;
         if (param.containsKey("UserpollingWaitSeconds")) {
            userTimeout = Integer.parseInt((String)param.get("UserpollingWaitSeconds"));
         }

         rsp = CMQHttp.request(this.method, url, req, userTimeout);
         return rsp;
      } catch (Exception var11) {
         Exception e = var11;
         throw e;
      }
   }
}
